[Scummvm-cvs-logs] CVS: scummvm/common config-file.cpp,1.16,1.17 config-file.h,1.9,1.10 list.h,1.7,1.8 map.h,1.12,1.13 rect.h,1.13,1.14 str.cpp,1.21,1.22 str.h,1.13,1.14

Max Horn fingolfin at users.sourceforge.net
Thu Oct 2 10:44:13 CEST 2003


Update of /cvsroot/scummvm/scummvm/common
In directory sc8-pr-cvs1:/tmp/cvs-serv18298/common

Modified Files:
	config-file.cpp config-file.h list.h map.h rect.h str.cpp 
	str.h 
Log Message:
renamed namespace ScummVM to Common

Index: config-file.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/common/config-file.cpp,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -d -r1.16 -r1.17
--- config-file.cpp	18 Sep 2003 02:07:17 -0000	1.16
+++ config-file.cpp	2 Oct 2003 17:43:01 -0000	1.17
@@ -228,7 +228,7 @@
 	return count;
 }
 
-ScummVM::StringList Config::get_domains() {
+Common::StringList Config::get_domains() {
 	StringList domainNames;
 	DomainMap::Iterator d, end(domains.end());
 	for (d = domains.begin(); d != end; ++d) {

Index: config-file.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/common/config-file.h,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -d -r1.9 -r1.10
--- config-file.h	1 Aug 2003 12:18:35 -0000	1.9
+++ config-file.h	2 Oct 2003 17:43:01 -0000	1.10
@@ -30,10 +30,10 @@
 
 class Config {
 public:
-	typedef ScummVM::String String;
-	typedef ScummVM::StringList StringList;
-	typedef ScummVM::StringMap StringMap;
-	typedef ScummVM::Map<String, StringMap> DomainMap;
+	typedef Common::String String;
+	typedef Common::StringList StringList;
+	typedef Common::StringMap StringMap;
+	typedef Common::Map<String, StringMap> DomainMap;
 
 	Config (const String & = String("config.cfg"), const String & = String("default"));
 	const char *get(const String &key, const String &dom = String()) const;

Index: list.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/common/list.h,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -d -r1.7 -r1.8
--- list.h	21 Aug 2003 13:39:19 -0000	1.7
+++ list.h	2 Oct 2003 17:43:01 -0000	1.8
@@ -24,7 +24,7 @@
 #include "common/scummsys.h"
 #include <assert.h>
 
-namespace ScummVM {
+namespace Common {
 
 template <class T>
 class List {
@@ -126,6 +126,6 @@
 	}
 };
 
-} // End of namespace ScummVM
+} // End of namespace Common
 
 #endif

Index: map.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/common/map.h,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -d -r1.12 -r1.13
--- map.h	2 Oct 2003 17:07:50 -0000	1.12
+++ map.h	2 Oct 2003 17:43:01 -0000	1.13
@@ -23,7 +23,7 @@
 
 #include "common/scummsys.h"
 
-namespace ScummVM {
+namespace Common {
 
 template <class Key, class Value>
 class Map {
@@ -247,6 +247,6 @@
 
 typedef Map<String, String> StringMap;
 
-}	// End of namespace ScummVM
+}	// End of namespace Common
 
 #endif

Index: rect.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/common/rect.h,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -d -r1.13 -r1.14
--- rect.h	21 Aug 2003 13:39:19 -0000	1.13
+++ rect.h	2 Oct 2003 17:43:01 -0000	1.14
@@ -25,7 +25,7 @@
 #include "common/scummsys.h"
 #include "common/util.h"
 
-namespace ScummVM {
+namespace Common {
 
 /*! 	@brief simple class for handling both 2D position and size
 
@@ -108,6 +108,6 @@
 	}
 };
 
-}	// End of namespace ScummVM
+}	// End of namespace Common
 
 #endif

Index: str.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/common/str.cpp,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -d -r1.21 -r1.22
--- str.cpp	21 Aug 2003 13:39:19 -0000	1.21
+++ str.cpp	2 Oct 2003 17:43:01 -0000	1.22
@@ -23,7 +23,7 @@
 
 #include <ctype.h>
 
-namespace ScummVM {
+namespace Common {
 
 String::String(const char *str, int len) {
 	_refCount = new int(1);
@@ -266,4 +266,4 @@
 	return x != y;
 }
 
-}	// End of namespace ScummVM
+}	// End of namespace Common

Index: str.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/common/str.h,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -d -r1.13 -r1.14
--- str.h	21 Aug 2003 13:39:19 -0000	1.13
+++ str.h	2 Oct 2003 17:43:01 -0000	1.14
@@ -27,7 +27,7 @@
 #include <assert.h>
 #include <string.h>
 
-namespace ScummVM {
+namespace Common {
 
 /*
  TODO
@@ -141,6 +141,6 @@
 	}
 };
 
-}	// End of namespace ScummVM
+}	// End of namespace Common
 
 #endif





More information about the Scummvm-git-logs mailing list